@@ -1,7 +1,7 @@
 #==============================================================================
 # Default link functions ------------------------------------------------------
 #==============================================================================
-#' @title Logit link function (for estimation with \code{maxlogL})
+#' @title Logit link function (for estimation with \code{maxlogL} object)
 #' @family link functions
 #'
 #' @description
@@ -47,14 +47,14 @@
 #' @seealso \code{\link{maxlogL}}
 #'
 logit_link <- function(){
-  name <- "Logit"
+  name <- "logit"
   g <- function(x) log(x/(1-x))
   g_inv <- function(x) exp(x)/(exp(x)+1)
   out <- list(name = name, g = g, g_inv = g_inv)
   return(out)
 }
 #=============================================================================#
-#' @title Logarithmic link function (for estimation with \code{maxlogL})
+#' @title Logarithmic link function (for estimation with \code{maxlogL} object)
 #' @family link functions
 #'
 #' @description
@@ -99,14 +99,14 @@ logit_link <- function(){
 #' @seealso \code{\link{maxlogL}}
 #'
 log_link <- function(){
-  name <- "Log"
+  name <- "log"
   g <- function(x) log(x)
   g_inv <- function(x) exp(x)
   out <- list(name = name, g = g, g_inv = g_inv)
   return(out)
 }
 #=============================================================================#
-#' @title Negative inverse link function (for estimation with \code{maxlogL})
+#' @title Negative inverse link function (for estimation with \code{maxlogL} object)
 #' @family link functions
 #'
 #' @description
